@@ -25,7 +25,6 @@
 #include "MessageCore/MailingList"
 #include "MessageCore/StringUtil"
 
-#include <KProtocolManager>
 #include <KMime/Message>
 #include <kmime/kmime_mdn.h>
 #include <kmime/kmime_dateformatter.h>
@@ -36,9 +35,7 @@
 
 using namespace MessageCore;
 
-namespace MessageHelper
-{
-
+namespace MessageHelper {
 void initHeader(const KMime::Message::Ptr &message, const KIdentityManagement::IdentityManager *identMan, uint id)
 {
     applyIdentity(message, identMan, id);
@@ -50,8 +47,7 @@ void initHeader(const KMime::Message::Ptr &message, const KIdentityManagement::I
     message->contentType()->setMimeType("text/plain");
 }
 
-void initFromMessage(const KMime::Message::Ptr &msg, const KMime::Message::Ptr &origMsg,
-                     KIdentityManagement::IdentityManager *identMan, uint id, bool idHeaders)
+void initFromMessage(const KMime::Message::Ptr &msg, const KMime::Message::Ptr &origMsg, KIdentityManagement::IdentityManager *identMan, uint id, bool idHeaders)
 {
     if (idHeaders) {
         MessageHelper::initHeader(msg, identMan, id);
@@ -71,8 +67,8 @@ void initFromMessage(const KMime::Message::Ptr &msg, const KMime::Message::Ptr &
 
 void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement::IdentityManager *identMan, uint id)
 {
-    const KIdentityManagement::Identity &ident =
-        identMan->identityForUoidOrDefault(id);
+    const KIdentityManagement::Identity &ident
+        = identMan->identityForUoidOrDefault(id);
 
     if (ident.fullEmailAddr().isEmpty()) {
         message->removeHeader<KMime::Headers::From>();
@@ -136,22 +132,6 @@ void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement
         message->setHeader(header);
     }
 
-    if (ident.drafts().isEmpty()) {
-        message->removeHeader("X-KMail-Drafts");
-    } else {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Drafts");
-        header->fromUnicodeString(ident.drafts(), "utf-8");
-        message->setHeader(header);
-    }
-
-    if (ident.templates().isEmpty()) {
-        message->removeHeader("X-KMail-Templates");
-    } else {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Templates");
-        header->fromUnicodeString(ident.templates(), "utf-8");
-        message->setHeader(header);
-    }
-
     if (ident.disabledFcc()) {
         KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-FccDisabled");
         header->fromUnicodeString(QStringLiteral("true"), "utf-8");
@@ -165,8 +145,8 @@ KMime::Types::AddrSpecList extractAddrSpecs(const KMime::Message::Ptr &msg, cons
 {
     KMime::Types::AddrSpecList result;
     if (auto hrd = msg->headerByType(header.constData())) {
-        KMime::Types::AddressList al =
-            MessageCore::StringUtil::splitAddressField(hrd->asUnicodeString().toUtf8());
+        KMime::Types::AddressList al
+            = MessageCore::StringUtil::splitAddressField(hrd->asUnicodeString().toUtf8());
         KMime::Types::AddressList::const_iterator alend(al.constEnd());
         for (KMime::Types::AddressList::const_iterator ait = al.constBegin(); ait != alend; ++ait) {
             KMime::Types::MailboxList::const_iterator mitEnd((*ait).mailboxList.constEnd());
@@ -178,64 +158,6 @@ KMime::Types::AddrSpecList extractAddrSpecs(const KMime::Message::Ptr &msg, cons
     return result;
 }
 
-QString cleanSubject(const KMime::Message::Ptr &msg)
-{
-    return cleanSubject(msg, MessageComposer::MessageComposerSettings::self()->replyPrefixes() + MessageComposer::MessageComposerSettings::self()->forwardPrefixes(),
-                        true, QString()).trimmed();
-}
-
-QString cleanSubject(const KMime::Message::Ptr &msg, const QStringList &prefixRegExps,
-                     bool replace, const QString &newPrefix)
-{
-    return replacePrefixes(msg->subject()->asUnicodeString(), prefixRegExps, replace,
-                           newPrefix);
-}
-
-QString forwardSubject(const KMime::Message::Ptr &msg)
-{
-    return cleanSubject(msg, MessageComposer::MessageComposerSettings::self()->forwardPrefixes(),
-                        MessageComposer::MessageComposerSettings::self()->replaceForwardPrefix(), QStringLiteral("Fwd:"));
-}
-
-QString replySubject(const KMime::Message::Ptr &msg)
-{
-    return cleanSubject(msg, MessageComposer::MessageComposerSettings::self()->replyPrefixes(),
-                        MessageComposer::MessageComposerSettings::self()->replaceReplyPrefix(), QStringLiteral("Re:"));
-}
-
-QString replacePrefixes(const QString &str, const QStringList &prefixRegExps,
-                        bool replace, const QString &newPrefix)
-{
-    bool recognized = false;
-    // construct a big regexp that
-    // 1. is anchored to the beginning of str (sans whitespace)
-    // 2. matches at least one of the part regexps in prefixRegExps
-    QString bigRegExp = QStringLiteral("^(?:\\s+|(?:%1))+\\s*")
-                        .arg(prefixRegExps.join(QStringLiteral(")|(?:")));
-    QRegExp rx(bigRegExp, Qt::CaseInsensitive);
-    if (rx.isValid()) {
-        QString tmp = str;
-        if (rx.indexIn(tmp) == 0) {
-            recognized = true;
-            if (replace) {
-                return tmp.replace(0, rx.matchedLength(), newPrefix + QLatin1Char(' '));
-            }
-        }
-    } else {
-        qCWarning(MESSAGECOMPOSER_LOG) << "bigRegExp = \""
-                                       << bigRegExp << "\"\n"
-                                       << "prefix regexp is invalid!";
-        // try good ole Re/Fwd:
-        recognized = str.startsWith(newPrefix);
-    }
-
-    if (!recognized) {
-        return newPrefix + QLatin1Char(' ') + str;
-    } else {
-        return str;
-    }
-}
-
 void setAutomaticFields(const KMime::Message::Ptr &msg, bool aIsMulti)
 {
     auto header = msg->header<KMime::Headers::MIMEVersion>(true);
@@ -248,11 +170,4 @@ void setAutomaticFields(const KMime::Message::Ptr &msg, bool aIsMulti)
         msg->contentType()->setBoundary(KMime::multiPartBoundary());
     }
 }
-
-QString stripOffPrefixes(const QString &str)
-{
-    return replacePrefixes(str, MessageComposer::MessageComposerSettings::self()->replyPrefixes() + MessageComposer::MessageComposerSettings::self()->forwardPrefixes(),
-                           true, QString()).trimmed();
-}
-
 }
