@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,8 +24,7 @@
 #include <KContacts/Addressee>
 #include "composer/keyresolver.h"
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class SaveContactPreferenceJob : public QObject
 {
     Q_OBJECT
