@@ -29,7 +29,7 @@
 #include <QGridLayout>
 #include <QPushButton>
 #include <QFrame>
-#include <QHash>
+#include <QMap>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -97,7 +97,6 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     , d(new Private(this))
 {
     setAttribute(Qt::WA_DeleteOnClose);
-    setWindowModality(Qt::ApplicationModal);   // FIXME: Sure ?
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -118,23 +117,28 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     d->mThemeList->setSortingEnabled(true);
     g->addWidget(d->mThemeList, 0, 0, 7, 1);
 
-    connect(d->mThemeList, SIGNAL(itemClicked(QListWidgetItem*)),
-            SLOT(themeListItemClicked(QListWidgetItem*)));
+    connect(d->mThemeList, &ThemeListWidget::itemClicked,
+            this, [this](QListWidgetItem *item) {
+        d->themeListItemClicked(item);
+    });
 
     d->mNewThemeButton = new QPushButton(i18n("New Theme"), base);
     d->mNewThemeButton->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
     d->mNewThemeButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     g->addWidget(d->mNewThemeButton, 0, 1);
 
-    connect(d->mNewThemeButton, &QPushButton::clicked, this, [this]() {d->newThemeButtonClicked(); });
+    connect(d->mNewThemeButton, &QPushButton::clicked, this, [this]() {
+        d->newThemeButtonClicked();
+    });
 
     d->mCloneThemeButton = new QPushButton(i18n("Clone Theme"), base);
     d->mCloneThemeButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     d->mCloneThemeButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     g->addWidget(d->mCloneThemeButton, 1, 1);
 
-    connect(d->mCloneThemeButton, SIGNAL(clicked()),
-            SLOT(cloneThemeButtonClicked()));
+    connect(d->mCloneThemeButton, &QPushButton::clicked, this, [this]() {
+        d->cloneThemeButtonClicked();
+    });
 
     QFrame *f = new QFrame(base);
     f->setFrameStyle(QFrame::Sunken | QFrame::HLine);
@@ -144,13 +148,15 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     d->mExportThemeButton = new QPushButton(i18n("Export Theme..."), base);
     g->addWidget(d->mExportThemeButton, 3, 1);
 
-    connect(d->mExportThemeButton, SIGNAL(clicked()),
-            SLOT(exportThemeButtonClicked()));
+    connect(d->mExportThemeButton, &QPushButton::clicked, this, [this]() {
+        d->exportThemeButtonClicked();
+    });
 
     d->mImportThemeButton = new QPushButton(i18n("Import Theme..."), base);
     g->addWidget(d->mImportThemeButton, 4, 1);
-    connect(d->mImportThemeButton, SIGNAL(clicked()),
-            SLOT(importThemeButtonClicked()));
+    connect(d->mImportThemeButton, &QPushButton::clicked, this, [this]() {
+        d->importThemeButtonClicked();
+    });
 
     f = new QFrame(base);
     f->setFrameStyle(QFrame::Sunken | QFrame::HLine);
@@ -162,18 +168,23 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     d->mDeleteThemeButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     g->addWidget(d->mDeleteThemeButton, 6, 1);
 
-    connect(d->mDeleteThemeButton, SIGNAL(clicked()), SLOT(deleteThemeButtonClicked()));
+    connect(d->mDeleteThemeButton, &QPushButton::clicked, this, [this]() {
+        d->deleteThemeButtonClicked();
+    });
 
     d->mEditor = new ThemeEditor(base);
     g->addWidget(d->mEditor, 8, 0, 1, 2);
 
-    connect(d->mEditor, SIGNAL(themeNameChanged()),
-            SLOT(editedThemeNameChanged()));
+    connect(d->mEditor, &ThemeEditor::themeNameChanged, this, [this]() {
+        d->editedThemeNameChanged();
+    });
 
     g->setColumnStretch(0, 1);
     g->setRowStretch(4, 1);
 
-    connect(okButton, SIGNAL(clicked()), SLOT(okButtonClicked()));
+    connect(okButton, &QPushButton::clicked, this, [this]() {
+        d->okButtonClicked();
+    });
 
     d->fillThemeList();
 }
@@ -256,10 +267,10 @@ void ConfigureThemesDialog::Private::editedThemeNameChanged()
 
 void ConfigureThemesDialog::Private::fillThemeList()
 {
-    const QHash< QString, Theme * > &sets = Manager::instance()->themes();
+    const QMap< QString, Theme * > &sets = Manager::instance()->themes();
 
-    QHash< QString, Theme * >::ConstIterator end(sets.constEnd());
-    for (QHash< QString, Theme * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
+    QMap< QString, Theme * >::ConstIterator end(sets.constEnd());
+    for (QMap< QString, Theme * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
         (void)new ThemeListWidgetItem(mThemeList, *(*it));
     }
 }
