@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2018-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,6 +21,7 @@
 
 #include <QWidget>
 #include "messageviewer_private_export.h"
+class QTreeWidget;
 namespace MessageViewer {
 class MESSAGEVIEWER_TESTS_EXPORT DKIMManagerKeyWidget : public QWidget
 {
@@ -28,6 +29,12 @@ class MESSAGEVIEWER_TESTS_EXPORT DKIMManagerKeyWidget : public QWidget
 public:
     explicit DKIMManagerKeyWidget(QWidget *parent = nullptr);
     ~DKIMManagerKeyWidget();
+
+    //TODO make it private ?
+    void loadKeys();
+    void saveKeys();
+private:
+    QTreeWidget *mTreeWidget = nullptr;
 };
 }
 
