@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,7 +35,7 @@ public:
 public:
     const char *name() const override;
 
-    QString format(KMime::Message *message) const override;
+    Q_REQUIRED_RESULT QString format(KMime::Message *message) const override;
 
     void setAbsolutePath(const QString &);
     void setMainFilename(const QString &);
