@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * Copyright (C) 2011-2017 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2011-2019 Laurent Montel <montel@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +30,7 @@ class KActionCollection;
 
 class Ui_CustomTemplatesBase;
 
-namespace TemplateParser
-{
+namespace TemplateParser {
 class CustomTemplateItem;
 
 class TEMPLATEPARSER_EXPORT CustomTemplates : public QWidget
@@ -46,8 +45,7 @@ public:
     };
 
 public:
-    explicit CustomTemplates(const QList<KActionCollection *> &actionCollection,
-                             QWidget *parent = nullptr);
+    explicit CustomTemplates(const QList<KActionCollection *> &actionCollection, QWidget *parent = nullptr);
     ~CustomTemplates();
 
     void load();
@@ -87,19 +85,13 @@ private:
     /// templates, which changes the UI without user action
     bool mBlockChangeSignal;
 
-    Ui_CustomTemplatesBase *mUi;
+    Ui_CustomTemplatesBase *mUi = nullptr;
 };
 
 class CustomTemplateItem : public QTreeWidgetItem
 {
 public:
-    explicit CustomTemplateItem(QTreeWidget *parent,
-                                const QString &name,
-                                const QString &content,
-                                const QKeySequence &shortcut,
-                                CustomTemplates::Type type,
-                                const QString &to,
-                                const QString &cc);
+    explicit CustomTemplateItem(QTreeWidget *parent, const QString &name, const QString &content, const QKeySequence &shortcut, CustomTemplates::Type type, const QString &to, const QString &cc);
     ~CustomTemplateItem();
     void setCustomType(CustomTemplates::Type type);
     CustomTemplates::Type customType() const;
@@ -131,15 +123,11 @@ class CustomTemplateItemDelegate : public QStyledItemDelegate
     Q_OBJECT
 public:
     explicit CustomTemplateItemDelegate(QObject *parent = nullptr);
-    ~CustomTemplateItemDelegate();
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const override;
-
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const override;
+    ~CustomTemplateItemDelegate() override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 };
-
 }
 
 #endif
