@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,8 +17,6 @@
    Boston, MA 02110-1301, USA.
 */
 #include "webenginescript.h"
-#include <QDebug>
-#include <QtWebEngine/QtWebEngineVersion>
 using namespace WebEngineViewer;
 
 QString WebEngineScript::findAllImages()
@@ -127,11 +125,7 @@ QString WebEngineScript::searchElementPosition(const QString &elementStr)
 
 static QString scrollTop()
 {
-#if QTWEBENGINE_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     return QStringLiteral("document.documentElement.scrollTop");
-#else
-    return QStringLiteral("document.body.scrollTop");
-#endif
 }
 
 QString WebEngineScript::scrollPercentage(int percent)
