@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,8 +24,7 @@
 #include "webengineviewer_export.h"
 #include <QPoint>
 class QWebEnginePage;
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class WebHitTestResult;
 class WebHitTestPrivate;
 class WEBENGINEVIEWER_EXPORT WebHitTest : public QObject
